============
Optimization
============

Optimization commands are used to perform topology, shape, or sizing optimization of your model given a set of objectives and a set of restrictions.

Create optimization tasks
-------------------------

.. autoclass:: abaqus.Optimization.OptimizationTaskModel.OptimizationTaskModel
    :noindex:
    :members:

Assign features to optimization tasks
-------------------------------------

.. autoclass:: abaqus.Optimization.OptimizationTask.OptimizationTask
    :members:

    .. autoclasstoc::


Object features
---------------

BeadFixedRegion
~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Optimization.BeadFixedRegion.BeadFixedRegion
    :members:

    .. autoclasstoc::

BeadGrowth
~~~~~~~~~~

.. autoclass:: abaqus.Optimization.BeadGrowth.BeadGrowth
    :members:

    .. autoclasstoc::

BeadPenetrationCheck
~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Optimization.BeadPenetrationCheck.BeadPenetrationCheck
    :members:

    .. autoclasstoc::

BeadPlanarSymmetry
~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Optimization.BeadPlanarSymmetry.BeadPlanarSymmetry
    :members:

    .. autoclasstoc::

BeadPointSymmetry
~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Optimization.BeadPointSymmetry.BeadPointSymmetry
    :members:

    .. autoclasstoc::

BeadRotationalSymmetry
~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Optimization.BeadRotationalSymmetry.BeadRotationalSymmetry
    :members:

    .. autoclasstoc::

BeadTask
~~~~~~~~

.. autoclass:: abaqus.Optimization.BeadTask.BeadTask
    :members:

    .. autoclasstoc::

CombinedTermDesignResponse
~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Optimization.CombinedTermDesignResponse.CombinedTermDesignResponse
    :members:

    .. autoclasstoc::

DesignDirection
~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Optimization.DesignDirection.DesignDirection
    :members:

    .. autoclasstoc::

DesignResponse
~~~~~~~~~~~~~~

.. autoclass:: abaqus.Optimization.DesignResponse.DesignResponse
    :members:

    .. autoclasstoc::

DrillControl
~~~~~~~~~~~~

.. autoclass:: abaqus.Optimization.DrillControl.DrillControl
    :members:

    .. autoclasstoc::

FixedRegion
~~~~~~~~~~~

.. autoclass:: abaqus.Optimization.FixedRegion.FixedRegion
    :members:

    .. autoclasstoc::

FrozenArea
~~~~~~~~~~

.. autoclass:: abaqus.Optimization.FrozenArea.FrozenArea
    :members:

    .. autoclasstoc::

GeometricRestriction
~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Optimization.GeometricRestriction.GeometricRestriction
    :members:

    .. autoclasstoc::

Growth
~~~~~~

.. autoclass:: abaqus.Optimization.Growth.Growth
    :members:

    .. autoclasstoc::

LocalStopCondition
~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Optimization.LocalStopCondition.LocalStopCondition
    :members:

    .. autoclasstoc::

ObjectiveFunction
~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Optimization.ObjectiveFunction.ObjectiveFunction
    :members:

    .. autoclasstoc::

OptimizationConstraint
~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Optimization.OptimizationConstraint.OptimizationConstraint
    :members:

    .. autoclasstoc::

OptimizationObjective
~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Optimization.OptimizationObjective.OptimizationObjective
    :members:

    .. autoclasstoc::

OptimizationObjectiveArray
~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Optimization.OptimizationObjectiveArray.OptimizationObjectiveArray
    :members:

    .. autoclasstoc::

PenetrationCheck
~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Optimization.PenetrationCheck.PenetrationCheck
    :members:

    .. autoclasstoc::

ShapeDemoldControl
~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Optimization.ShapeDemoldControl.ShapeDemoldControl
    :members:

    .. autoclasstoc::

ShapeMemberSize
~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Optimization.ShapeMemberSize.ShapeMemberSize
    :members:

    .. autoclasstoc::

ShapePlanarSymmetry
~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Optimization.ShapePlanarSymmetry.ShapePlanarSymmetry
    :members:

    .. autoclasstoc::

ShapePointSymmetry
~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Optimization.ShapePointSymmetry.ShapePointSymmetry
    :members:

    .. autoclasstoc::

ShapeRotationalSymmetry
~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Optimization.ShapeRotationalSymmetry.ShapeRotationalSymmetry
    :members:

    .. autoclasstoc::

ShapeTask
~~~~~~~~~

.. autoclass:: abaqus.Optimization.ShapeTask.ShapeTask
    :members:

    .. autoclasstoc::

SingleTermDesignResponse
~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Optimization.SingleTermDesignResponse.SingleTermDesignResponse
    :members:

    .. autoclasstoc::

SizingClusterAreas
~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Optimization.SizingClusterAreas.SizingClusterAreas
    :members:

    .. autoclasstoc::

SizingCyclicSymmetry
~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Optimization.SizingCyclicSymmetry.SizingCyclicSymmetry
    :members:

    .. autoclasstoc::

SizingFrozenArea
~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Optimization.SizingFrozenArea.SizingFrozenArea
    :members:

    .. autoclasstoc::

SizingMemberSize
~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Optimization.SizingMemberSize.SizingMemberSize
    :members:

    .. autoclasstoc::

SizingPlanarSymmetry
~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Optimization.SizingPlanarSymmetry.SizingPlanarSymmetry
    :members:

    .. autoclasstoc::

SizingPointSymmetry
~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Optimization.SizingPointSymmetry.SizingPointSymmetry
    :members:

    .. autoclasstoc::

SizingRotationalSymmetry
~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Optimization.SizingRotationalSymmetry.SizingRotationalSymmetry
    :members:

    .. autoclasstoc::

SizingTask
~~~~~~~~~~

.. autoclass:: abaqus.Optimization.SizingTask.SizingTask
    :members:

    .. autoclasstoc::

SlideRegionControl
~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Optimization.SlideRegionControl.SlideRegionControl
    :members:

    .. autoclasstoc::

StampControl
~~~~~~~~~~~~

.. autoclass:: abaqus.Optimization.StampControl.StampControl
    :members:

    .. autoclasstoc::

StepOption
~~~~~~~~~~

.. autoclass:: abaqus.Optimization.StepOption.StepOption
    :members:

    .. autoclasstoc::

StepOptionArray
~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Optimization.StepOptionArray.StepOptionArray
    :members:

    .. autoclasstoc::

StopCondition
~~~~~~~~~~~~~

.. autoclass:: abaqus.Optimization.StopCondition.StopCondition
    :members:

    .. autoclasstoc::

TopologyCyclicSymmetry
~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Optimization.TopologyCyclicSymmetry.TopologyCyclicSymmetry
    :members:

    .. autoclasstoc::

TopologyDemoldControl
~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Optimization.TopologyDemoldControl.TopologyDemoldControl
    :members:

    .. autoclasstoc::

TopologyMemberSize
~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Optimization.TopologyMemberSize.TopologyMemberSize
    :members:

    .. autoclasstoc::

TopologyMillingControl
~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Optimization.TopologyMillingControl.TopologyMillingControl
    :members:

    .. autoclasstoc::

TopologyPlanarSymmetry
~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Optimization.TopologyPlanarSymmetry.TopologyPlanarSymmetry
    :members:

    .. autoclasstoc::

TopologyPointSymmetry
~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Optimization.TopologyPointSymmetry.TopologyPointSymmetry
    :members:

    .. autoclasstoc::

TopologyRotationalSymmetry
~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Optimization.TopologyRotationalSymmetry.TopologyRotationalSymmetry
    :members:

    .. autoclasstoc::

TopologyTask
~~~~~~~~~~~~

.. autoclass:: abaqus.Optimization.TopologyTask.TopologyTask
    :members:

    .. autoclasstoc::

TurnControl
~~~~~~~~~~~

.. autoclass:: abaqus.Optimization.TurnControl.TurnControl
    :members:

    .. autoclasstoc::

